using System;
using System.Diagnostics;
using System.Runtime;
using System.Reflection;
using System.IO;
using System.Drawing;
using System.Drawing.Imaging;

using Syncfusion.Windows.Forms.Diagram;
using Syncfusion.Windows.Forms.Diagram.Controls;

using DWS.ITMS.Actuate.ObjectType;

namespace DWS.ITMS.Actuate.ObjectType.Chart
{
	#region Model

	/// <summary>
	/// Symbol Model implementation for a Chart Symbol (Generic Chart Object)
	/// </summary>
	public class ChartSymbolModel : DWS.ITMS.Actuate.ObjectType.SymbolModelBase
	{
		/// <summary>
		/// Create a new Chart Symbol Model with a type but without an object.
		/// </summary>
		/// <param name="type">The type to associate with the model.</param>
		public ChartSymbolModel(object type) : this(type, null)
		{
		}

		/// <summary>
		/// Create a new Chart Symbol Model given a type and object to associate.
		/// </summary>
		/// <param name="type">The type to associate with the model.</param>
		/// <param name="obj">The object to associate with the model.</param>
		public ChartSymbolModel(object type, object obj) : base(type, typeof(ChartSymbol), obj)
		{
			// Set base properties for the control
			base.AutoHidePorts					= true;
			base.BackgroundStyle.Color			= Color.White;
			base.BackgroundStyle.Type			= BackgroundStyle.BackgroundType.Solid;
			base.BoundaryConstraintsEnabled		= false;
			base.CenterPortEnabled				= false;
			base.Name							= "Chart";
			base.FillStyle.Color				= Color.White;
			base.FillStyle.Type					= FillStyle.FillType.Solid;
			base.ShadowStyle.Visible			= true;
		}
	}

	#endregion


	#region Symbol

	/// <summary>
	/// Symbol implementation for a Chart Symbol (Generic Chart Object)
	/// </summary>
	public class ChartSymbol : DWS.ITMS.Actuate.ObjectType.SymbolBase
	{
		#region Variables

		private static PointF[] _curvePoints1 = new PointF[]
		{
			new PointF(0, INITIAL_HEIGHT),
			new PointF(10, INITIAL_HEIGHT - 14),
			new PointF(50, INITIAL_HEIGHT - 40),
			new PointF(80, INITIAL_HEIGHT - 64),
			new PointF(INITIAL_WIDTH, INITIAL_HEIGHT - 30)
		};

		private static PointF[] _curvePoints2 = new PointF[]
		{
			new PointF(0, INITIAL_HEIGHT - 50),
			new PointF(10, INITIAL_HEIGHT - 24),
			new PointF(50, INITIAL_HEIGHT - 70),
			new PointF(80, INITIAL_HEIGHT - 14),
			new PointF(INITIAL_WIDTH, INITIAL_HEIGHT - 90)
		};

		private static PointF[] _curvePoints3 = new PointF[]
		{
			new PointF(0, INITIAL_HEIGHT),
			new PointF(10, INITIAL_HEIGHT - 80),
			new PointF(50, INITIAL_HEIGHT - 5),
			new PointF(80, INITIAL_HEIGHT - 34),
			new PointF(INITIAL_WIDTH, INITIAL_HEIGHT - 90)
		};

		#endregion


		#region Constructor Destructor

		/// <summary>
		/// Standard Constructor.
		/// </summary>
		public ChartSymbol()
		{
			InitSymbol();
		}

		#endregion


		#region Methods

		/// <summary>
		/// Initialize the symbol (its visual representation)
		/// </summary>
		public override void InitSymbol()
		{
			base.InitSymbol();

			// Construct the new content
			Syncfusion.Windows.Forms.Diagram.Line		line;
			Syncfusion.Windows.Forms.Diagram.Curve		curve;

			// Add the bounding box
			line	= new Line(new PointF(0, 0), new PointF(0, INITIAL_HEIGHT));
			line.LineStyle.LineWidth	= 2;
			line.LineStyle.LineColor	= Color.Black;
			AppendChild(line);

			line	= new Line(new PointF(0, INITIAL_HEIGHT), new PointF(INITIAL_WIDTH, INITIAL_HEIGHT));
			line.LineStyle.LineWidth	= 2;
			line.LineStyle.LineColor	= Color.Black;
			AppendChild(line);

			// Add the seperator lines
			for(int i = 0; i < INITIAL_HEIGHT; i += 10)
			{
				line	= new Line(new PointF(0, i), new PointF(5, i));
				line.LineStyle.LineWidth	= 1;
				line.LineStyle.LineColor	= Color.Black;
				AppendChild(line);
			}

			for(int i = 0; i < INITIAL_WIDTH; i += 10)
			{
				line	= new Line(new PointF(i, INITIAL_HEIGHT - 5), new PointF(i, INITIAL_HEIGHT));
				line.LineStyle.LineWidth	= 1;
				line.LineStyle.LineColor	= Color.Black;
				AppendChild(line);
			}

			// Create some stylistic curves
			curve	= new Curve(_curvePoints1);
			curve.LineStyle.LineWidth		= 2;
			curve.LineStyle.LineColor		= Color.FromArgb(255, 128, 0, 0);
			this.
			AppendChild(curve);

			curve	= new Curve(_curvePoints2);
			curve.LineStyle.LineWidth		= 2;
			curve.LineStyle.LineColor		= Color.FromArgb(255, 0, 128, 0);
			AppendChild(curve);

			curve	= new Curve(_curvePoints3);
			curve.LineStyle.LineWidth		= 2;
			curve.LineStyle.LineColor		= Color.FromArgb(255, 0, 0, 128);
			AppendChild(curve);
		}

		#endregion
	}

	#endregion
}
