using System;
using System.Diagnostics;
using System.Runtime;
using System.Reflection;
using System.IO;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Drawing.Imaging;

using Syncfusion.Windows.Forms.Diagram;
using Syncfusion.Windows.Forms.Diagram.Controls;

using DWS.ITMS.Actuate.ObjectType;

namespace DWS.ITMS.Actuate.ObjectType.CrossTab
{
	#region Model

	/// <summary>
	/// Symbol Model implementation for a CrossTab Symbol (Generic CrossTab Object)
	/// </summary>
	public class CrossTabSymbolModel : DWS.ITMS.Actuate.ObjectType.SymbolModelBase
	{
		/// <summary>
		/// Create a new CrossTab Symbol Model with a type but without an object.
		/// </summary>
		/// <param name="type">The type to associate with the model.</param>
		public CrossTabSymbolModel(object type) : this(type, null)
		{
		}

		/// <summary>
		/// Create a new CrossTab Symbol Model given a type and object to associate.
		/// </summary>
		/// <param name="type">The type to associate with the model.</param>
		/// <param name="obj">The object to associate with the model.</param>
		public CrossTabSymbolModel(object type, object obj) : base(type, typeof(CrossTabSymbol), obj)
		{
			// Set base properties for the control
			base.AutoHidePorts					= true;
			base.BackgroundStyle.Color			= Color.White;
			base.BackgroundStyle.Type			= BackgroundStyle.BackgroundType.Solid;
			base.BoundaryConstraintsEnabled		= false;
			base.CenterPortEnabled				= false;
			base.Name							= "CrossTab";
			base.FillStyle.Color				= Color.White;
			base.FillStyle.Type					= FillStyle.FillType.Solid;
			base.ShadowStyle.Visible			= true;
		}
	}

	#endregion


	#region Symbol

	/// <summary>
	/// Symbol implementation for a CrossTab Symbol (Generic CrossTab Object)
	/// </summary>
	public class CrossTabSymbol : DWS.ITMS.Actuate.ObjectType.SymbolBase
	{
		#region Variables

		private static PointF[] _curvePoints1 = new PointF[]
		{
			new PointF(0, INITIAL_HEIGHT),
			new PointF(10, INITIAL_HEIGHT - 14),
			new PointF(50, INITIAL_HEIGHT - 40),
			new PointF(80, INITIAL_HEIGHT - 64),
			new PointF(INITIAL_WIDTH, INITIAL_HEIGHT - 30)
		};

		private static PointF[] _curvePoints2 = new PointF[]
		{
			new PointF(0, INITIAL_HEIGHT - 50),
			new PointF(10, INITIAL_HEIGHT - 24),
			new PointF(50, INITIAL_HEIGHT - 70),
			new PointF(80, INITIAL_HEIGHT - 14),
			new PointF(INITIAL_WIDTH, INITIAL_HEIGHT - 90)
		};

		private static PointF[] _curvePoints3 = new PointF[]
		{
			new PointF(0, INITIAL_HEIGHT),
			new PointF(10, INITIAL_HEIGHT - 80),
			new PointF(50, INITIAL_HEIGHT - 5),
			new PointF(80, INITIAL_HEIGHT - 34),
			new PointF(INITIAL_WIDTH, INITIAL_HEIGHT - 90)
		};

		#endregion


		#region Constructor Destructor

		/// <summary>
		/// Standard Constructor.
		/// </summary>
		public CrossTabSymbol()
		{
			InitSymbol();
		}

		#endregion


		#region Methods

		/// <summary>
		/// Initialize the symbol (its visual representation)
		/// </summary>
		public override void InitSymbol()
		{
			base.InitSymbol();

			// Construct the new content
			Syncfusion.Windows.Forms.Diagram.Line		line;
			Syncfusion.Windows.Forms.Diagram.Rectangle	rect;

			rect	= new Syncfusion.Windows.Forms.Diagram.Rectangle(0, 0, INITIAL_WIDTH, INITIAL_HEIGHT);
			rect.LineStyle.LineColor	= Color.Transparent;
			rect.FillStyle.Color		= Color.FromArgb(255, 240, 240, 240);
			rect.FillStyle.Type			= FillStyle.FillType.Solid;
			AppendChild(rect);

			// Add the "Grid" lines
			for(int i = 10; i < INITIAL_HEIGHT - 5; i += 10)
			{
				line	= new Line(new PointF(0, i), new PointF(INITIAL_WIDTH, i));
				line.LineStyle.LineColor	= Color.Black;
				line.LineStyle.LineWidth	= 1;
				AppendChild(line);
			}

			for(int i = 5; i < INITIAL_WIDTH; i += 10)
			{
				line	= new Line(new PointF(i, 10), new PointF(i, INITIAL_HEIGHT));
				line.LineStyle.DashStyle	= DashStyle.Dot;
				line.LineStyle.LineColor	= Color.Black;
				line.LineStyle.LineWidth	= 1;
				AppendChild(line);
			}
		}

		#endregion
	}

	#endregion
}
