using System;
using System.Diagnostics;
using System.Runtime;
using System.Reflection;
using System.IO;
using System.Drawing;
using System.Drawing.Imaging;

using Syncfusion.Windows.Forms.Diagram;
using Syncfusion.Windows.Forms.Diagram.Controls;

using DWS.ITMS.Actuate.ObjectType;

namespace DWS.ITMS.Actuate.ObjectType.Image
{
	#region Model

	/// <summary>
	/// Symbol Model implementation for a Image Symbol (Generic Image Object)
	/// </summary>
	public class ImageSymbolModel : DWS.ITMS.Actuate.ObjectType.SymbolModelBase
	{
		/// <summary>
		/// Create a new Image Symbol Model with a type but without an object.
		/// </summary>
		/// <param name="type">The type to associate with the model.</param>
		public ImageSymbolModel(object type) : this(type, null)
		{
		}

		/// <summary>
		/// Create a new Image Symbol Model given a type and object to associate.
		/// </summary>
		/// <param name="type">The type to associate with the model.</param>
		/// <param name="obj">The object to associate with the model.</param>
		public ImageSymbolModel(object type, object obj) : base(type, typeof(ImageSymbol), obj)
		{
			// Set base properties for the control
			base.AutoHidePorts					= true;
			base.BackgroundStyle.Color			= Color.White;
			base.BackgroundStyle.Type			= BackgroundStyle.BackgroundType.Solid;
			base.BoundaryConstraintsEnabled		= false;
			base.CenterPortEnabled				= false;
			base.Name							= "Image";
			base.FillStyle.Color				= Color.White;
			base.FillStyle.Type					= FillStyle.FillType.Solid;
			base.ShadowStyle.Visible			= true;
		}
	}

	#endregion


	#region Symbol

	/// <summary>
	/// Symbol implementation for a Image Symbol (Generic Image Object)
	/// </summary>
	public class ImageSymbol : DWS.ITMS.Actuate.ObjectType.SymbolBase
	{
		#region Variables

		private static PointF[] _curvePoints1 = new PointF[]
		{
			new PointF(0, INITIAL_HEIGHT),
			new PointF(10, INITIAL_HEIGHT - 14),
			new PointF(50, INITIAL_HEIGHT - 40),
			new PointF(80, INITIAL_HEIGHT - 64),
			new PointF(INITIAL_WIDTH, INITIAL_HEIGHT - 30)
		};

		private static PointF[] _curvePoints2 = new PointF[]
		{
			new PointF(0, INITIAL_HEIGHT - 50),
			new PointF(10, INITIAL_HEIGHT - 24),
			new PointF(50, INITIAL_HEIGHT - 70),
			new PointF(80, INITIAL_HEIGHT - 14),
			new PointF(INITIAL_WIDTH, INITIAL_HEIGHT - 90)
		};

		private static PointF[] _curvePoints3 = new PointF[]
		{
			new PointF(0, INITIAL_HEIGHT),
			new PointF(10, INITIAL_HEIGHT - 80),
			new PointF(50, INITIAL_HEIGHT - 5),
			new PointF(80, INITIAL_HEIGHT - 34),
			new PointF(INITIAL_WIDTH, INITIAL_HEIGHT - 90)
		};

		#endregion


		#region Constructor Destructor

		/// <summary>
		/// Standard Constructor.
		/// </summary>
		public ImageSymbol()
		{
			InitSymbol();
		}

		#endregion


		#region Methods

		/// <summary>
		/// Initialize the symbol (its visual representation)
		/// </summary>
		public override void InitSymbol()
		{
			base.InitSymbol();
		}

		#endregion
	}

	#endregion
}
