using System;
using System.Diagnostics;
using System.Runtime;
using System.Reflection;
using System.IO;
using System.Drawing;
using System.Drawing.Imaging;

using Syncfusion.Windows.Forms.Diagram;
using Syncfusion.Windows.Forms.Diagram.Controls;

using DWS.ITMS.Actuate.ObjectType;

namespace DWS.ITMS.Actuate.ObjectType.Text
{
	#region Model

	/// <summary>
	/// Symbol Model implementation for a Text Symbol (Generic Text Object)
	/// </summary>
	public class TextSymbolModel : DWS.ITMS.Actuate.ObjectType.SymbolModelBase
	{
		/// <summary>
		/// Create a new Text Symbol Model with a type but without an object.
		/// </summary>
		/// <param name="type">The type to associate with the model.</param>
		public TextSymbolModel(object type) : this(type, null)
		{
		}

		/// <summary>
		/// Create a new Text Symbol Model given a type and object to associate.
		/// </summary>
		/// <param name="type">The type to associate with the model.</param>
		/// <param name="obj">The object to associate with the model.</param>
		public TextSymbolModel(object type, object obj) : base(type, typeof(TextSymbol), obj)
		{
			// Set base properties for the control
			base.AutoHidePorts					= true;
			base.BackgroundStyle.Color			= Color.White;
			base.BackgroundStyle.Type			= BackgroundStyle.BackgroundType.Solid;
			base.BoundaryConstraintsEnabled		= false;
			base.CenterPortEnabled				= false;
			base.Name							= "Text";
			base.FillStyle.Color				= Color.White;
			base.FillStyle.Type					= FillStyle.FillType.Solid;
			base.ShadowStyle.Visible			= true;
		}
	}

	#endregion


	#region Symbol

	/// <summary>
	/// Symbol implementation for a Text Symbol (Generic Text Object)
	/// </summary>
	public class TextSymbol : DWS.ITMS.Actuate.ObjectType.SymbolBase
	{
		#region Variables

		private static PointF[] _curvePoints1 = new PointF[]
		{
			new PointF(0, INITIAL_HEIGHT),
			new PointF(10, INITIAL_HEIGHT - 14),
			new PointF(50, INITIAL_HEIGHT - 40),
			new PointF(80, INITIAL_HEIGHT - 64),
			new PointF(INITIAL_WIDTH, INITIAL_HEIGHT - 30)
		};

		private static PointF[] _curvePoints2 = new PointF[]
		{
			new PointF(0, INITIAL_HEIGHT - 50),
			new PointF(10, INITIAL_HEIGHT - 24),
			new PointF(50, INITIAL_HEIGHT - 70),
			new PointF(80, INITIAL_HEIGHT - 14),
			new PointF(INITIAL_WIDTH, INITIAL_HEIGHT - 90)
		};

		private static PointF[] _curvePoints3 = new PointF[]
		{
			new PointF(0, INITIAL_HEIGHT),
			new PointF(10, INITIAL_HEIGHT - 80),
			new PointF(50, INITIAL_HEIGHT - 5),
			new PointF(80, INITIAL_HEIGHT - 34),
			new PointF(INITIAL_WIDTH, INITIAL_HEIGHT - 90)
		};

		#endregion


		#region Constructor Destructor

		/// <summary>
		/// Standard Constructor.
		/// </summary>
		public TextSymbol()
		{
			InitSymbol();
		}

		#endregion


		#region Methods

		/// <summary>
		/// Initialize the symbol (its visual representation)
		/// </summary>
		public override void InitSymbol()
		{
			base.InitSymbol();

			// Construct the new content
			Syncfusion.Windows.Forms.Diagram.SymbolLabel	label;
			label						= new SymbolLabel();
			label.Anchor				= BoxPosition.Center;
			label.FontStyle.Family		= "Tahoma";
			label.FontStyle.Size		= 14;
			label.FontStyle.Bold		= true;
			label.Text					= "Abc";
			label.ReadOnly				= true;
			label.Anchor				= BoxPosition.Center;
			label.OffsetX				= 0;
			label.OffsetY				= 0;
			label.Location				= new PointF(0, 0);
			label.HorizontalAlignment	= StringAlignment.Center;
			label.VerticalAlignment		= StringAlignment.Center;
			label.EditStyle.AllowMove	= false;
			label.EditStyle.AllowSelect	= false;
			label.EditStyle.AllowResize	= false;
			label.EditStyle.Enabled		= false;
			AppendChild(label);
		}

		#endregion
	}

	#endregion
}
